@@ -9,7 +9,7 @@
 #rm ./*.log
 
 TOP_DIR=`pwd`
-NS3VER=3.13
+NS3VER=3.14.1
 NS3_DIR=$TOP_DIR/`ls -d ns-*`
 PYBINDGENV_DIR=$TOP_DIR/`ls -d pybindgen-0.*`
 NSC_DIR=$TOP_DIR/`ls -d nsc-*`
@@ -20,9 +20,19 @@ echo $DEBIAN_DIR
 ###############################################
 #clean top dir
 cd $TOP_DIR
-rm .config
 rm *.pyc
 
+##############################################
+# build waf
+cd $DEBIAN_DIR/waf-1.6
+./configure
+cp waf $NS3_DIR
+make distclean
+cd $DEBIAN_DIR/waf-1.5
+./configure
+cp waf $PYBINDGENV_DIR
+make distclean
+
 ################################################
 #clean ns3 dir
 cd $NS3_DIR
@@ -33,7 +43,6 @@ rm -rf ./doc/html
 rm -rf ./doc/latex
 
 make clean -C ./doc/manual
-cp $TOP_DIR/debian/upstream-back/manual-figures/*.png ./doc/manual/figures
 make clean -C ./doc/tutorial
 make clean -C ./doc/models
 
@@ -48,10 +57,12 @@ rm ./different.pcap
 rm -rf ./build
 find . -name '*.pyc' -exec rm {} \;
 find . -name '.waf-*' -exec rm -rf {} \;
+rm waf
 
 cd $PYBINDGENV_DIR
 find . -name '*.pyc' -exec rm {} \;
 find . -name '.waf-*' -exec rm -rf {} \;
+rm waf
 
 cd $NSC_DIR
 ./scons.py -c
